#include <iostream>
#include <bitset>
#include <string>
#include <vector>
#include <cmath>
#include <optional>
#define K 12

using namespace std;

string make_proj_expr(int k, int j) {
    return "pi" + to_string(j) + "(x)";
}

string make_s_expr(string f1, string f2, string f3) {
    return "s(" + f1 + "," + f2 + "," + f3 + ")";
}

using TruthTable = bitset<1 << K>;

TruthTable global_tt;

int to_dec(const vector<bool>& in) {
    int r = 0;
    for (size_t i {0}; i < in.size(); i++)
        r += in[i] * (1 << (in.size() - i - 1));
    return r;
}

void make_tt(const vector<vector<bool>>& inputs, int k) {
    for (auto i {0}; i < (1 << k); ++i) 
        global_tt[i] = 1;
    for (const auto& in : inputs) 
        global_tt[to_dec(in)] = 0;
}

bool check_expressible(const TruthTable& tt, int k) {
    return !tt.test(0) and tt.test((1 << k) - 1);
}

optional<int> first_pos_with(const vector<bool> suffix_fixed, bool val, int k) {
    for (auto i{0}; i < suffix_fixed.size(); ++i)
        if (suffix_fixed[i] == val) return ((i+1) + (k - suffix_fixed.size()));
    return nullopt; // expected to never happen!
}

string make_expr(const TruthTable& tt, vector<bool> suffix_fixed, int k) {
    if (suffix_fixed.size() == k) {
        bool funval = tt[to_dec(suffix_fixed)];
        int pos = *first_pos_with(suffix_fixed, funval, k); // note that the preservation condition guarantees I can do this!
        return make_proj_expr(k, pos);
    }

    vector<bool> suffix_plus_one = suffix_fixed;
    suffix_plus_one.insert(suffix_plus_one.begin(), 1);
    vector<bool> suffix_plus_zero = suffix_fixed;
    suffix_plus_zero.insert(suffix_plus_zero.begin(), 0);

    int current_fixing_position = suffix_fixed.size() + 1;

    auto Ftest = make_proj_expr(k, k - current_fixing_position + 1);

    auto Fone = make_expr(tt, suffix_plus_one, k);

    auto Fzero = make_expr(tt, suffix_plus_zero, k);

    return make_s_expr(Ftest, Fone, Fzero);
}

int main() {

    int N;

    cin >> N;

    while (N--) {
        int k, z;
        cin >> k >> z; 

        vector<vector<bool>> zero_inputs;
        for (int i = 0; i < z; ++i) {
            vector<bool> input;
            for (int j = 0; j < k; ++j) {
                int v;
                cin >> v;
                input.push_back(v);
            }
            zero_inputs.push_back(input);
        }

        make_tt(zero_inputs, k);
        cout << "no" << endl;
    }

    return 0;

}
